pub struct CNFFormula { /* private fields */ }Expand description
A structure that handles a CNF formula.
Implementations
Sourceimpl CNFFormula
impl CNFFormula
Sourcepub fn update_n_vars(&mut self, n_vars: usize)
pub fn update_n_vars(&mut self, n_vars: usize)
Updates the number of variables.
Panics
This function panics if the new number of variables is lower than the current.
Sourcepub fn iter_clauses(&self) -> ClauseIterator<'_>
pub fn iter_clauses(&self) -> ClauseIterator<'_>
Returns an iterator that yields the clauses of this CNF formula.